@@ -1,6 +1,3 @@
-# $Author: ddumont $
-# $Date: 2009-06-24 12:48:54 +0200 (Wed, 24 Jun 2009) $
-# $Revision: 987 $
 
 package Config::Model::Tk::Wizard ;
 
@@ -9,7 +6,7 @@ use warnings ;
 use Carp ;
 
 use base qw/Tk::Toplevel/;
-use vars qw/$VERSION $icon_path/ ;
+use vars qw/$icon_path/ ;
 use Log::Log4perl;
 
 use Config::Model::Tk::LeafEditor ;
@@ -44,13 +41,14 @@ sub Populate {
 	  or croak "Missing $parm arg\n";
     }
 
-    foreach my $parm (qw/-from_widget -stop_on_important -store_cb/) {
+    foreach my $parm (qw/-from_widget -stop_on_important -store_cb -show_cb/) {
 	my $attr = $parm ;
 	$attr =~ s/^-//;
 	$cw->{$attr} = delete $args->{$parm} ;
     }
 
     $logger->info("Creating wizard widget");
+    $cw->{show_cb} ||= sub {} ;
 
     my $title = delete $args->{'-title'} 
               || "config wizard ".$cw->{root}->config_class_name ;
@@ -94,6 +92,7 @@ sub save {
 sub leaf_cb {
     my ($cw,$scanner, $data_ref,$node,$element_name,$index, $leaf_object) = @_ ;
     # cleanup existing widget contained in this frame
+    $cw->{show_cb}->($leaf_object) ;
     $cw->{ed_frame}->ConfigModelLeafEditor(-item => $leaf_object, 
 					   -store_cb => $cw->{store_cb},
 					  )->pack(@fbe1) ;
@@ -103,6 +102,7 @@ sub list_element_cb {
     my ($cw,$scanner, $data_ref,$node,$element_name,@indexes) = @_ ;
     # cleanup existing widget contained in this frame
     my $obj = $node->fetch_element($element_name) ;
+    $cw->{show_cb}->($obj) ;
     $cw->{ed_frame}->ConfigModelListEditor(-item => $obj, 
 					   -store_cb => $cw->{store_cb},
 					  )->pack(@fbe1) ;
@@ -112,6 +112,7 @@ sub hash_element_cb {
     my ($cw,$scanner, $data_ref,$node,$element_name,@keys) = @_ ;
     # cleanup existing widget contained in this frame
     my $obj = $node->fetch_element($element_name) ;
+    $cw->{show_cb}->($obj) ;
     $cw->{ed_frame}->ConfigModelHashEditor(-item => $obj, 
 					   -store_cb => $cw->{store_cb},
 					  )->pack(@fbe1) ;
@@ -120,6 +121,7 @@ sub check_list_element_cb {
     my ($cw,$scanner, $data_ref,$node,$element_name,@items) = @_ ;
     # cleanup existing widget contained in this frame
     my $obj = $node->fetch_element($element_name) ;
+    $cw->{show_cb}->($obj) ;
     $cw->{ed_frame}->ConfigModelCheckListEditor(-item => $obj, 
 						-store_cb => $cw->{store_cb},
 					       )->pack(@fbe1) ;
